@@ -28,8 +28,8 @@
 __author__ = "Peter Fein"
 __email__ = "pfein@pobox.com"
 __url__ = "http://pypi.python.org/pypi/Factory/"
-__revision__ = "$Rev: 8 $"
-__version__ = (1, 1)
+__revision__ = "$Rev: 9 $"
+__version__ = (1, 2)
 
 import types
 import inspect
@@ -219,6 +219,9 @@ class Bunch(object):
 
     def __call__(self):
         return self.__class__(**self.__dict__)
+    
+    def get(self, name, default=None):
+        return getattr(self, name, default)
 
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
